aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIan Lance Taylor <iant@golang.org>2010-08-31 17:38:11 -0700
committerIan Lance Taylor <iant@golang.org>2010-08-31 17:38:11 -0700
commit9bd6b0afa4b08e23796c98a305b3c391a2327caf (patch)
tree881647d45cff9cea888450d3fd85de73a605459c
parent7a05b0f235fe27262e6ae8b3dc737a8d1e689808 (diff)
downloadgo-9bd6b0afa4b08e23796c98a305b3c391a2327caf.tar.gz
go-9bd6b0afa4b08e23796c98a305b3c391a2327caf.zip
test: Recognize gccgo error messages.
bug255.go:11: error: array bound truncated to integer bug255.go:12: error: array bound is not numeric bug255.go:13: error: array bound is not numeric bug255.go:14: error: array bound is not constant bug255.go:15: error: array bound overflows R=rsc CC=golang-dev https://golang.org/cl/2091042
-rw-r--r--test/fixedbugs/bug255.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/fixedbugs/bug255.go b/test/fixedbugs/bug255.go
index 4003a780cc..44427cfdb4 100644
--- a/test/fixedbugs/bug255.go
+++ b/test/fixedbugs/bug255.go
@@ -9,7 +9,7 @@ package main
var a [10]int // ok
var b [1e1]int // ok
var c [1.5]int // ERROR "truncated"
-var d ["abc"]int // ERROR "invalid array bound"
-var e [nil]int // ERROR "invalid array bound"
-var f [e]int // ERROR "invalid array bound"
+var d ["abc"]int // ERROR "invalid array bound|not numeric"
+var e [nil]int // ERROR "invalid array bound|not numeric"
+var f [e]int // ERROR "invalid array bound|not constant"
var g [1<<65]int // ERROR "overflows"